package com.sillycycle.bagleyd.panex;

/*
 * @(#)Panex.java
 *
 * Copyright 1994 - 2020  David A. Bagley, bagleyd AT verizon.net
 *
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and
 * that both that copyright notice and this permission notice appear in
 * supporting documentation, and that the name of the author not be
 * used in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.
 *
 * This program is distributed in the hope that it will be "useful",
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

import android.graphics.Canvas;
import android.graphics.Paint;

import com.sillycycle.bagleyd.panex.model.PanexFormat;
import com.sillycycle.bagleyd.panex.view.PanexGeometry;
import com.sillycycle.bagleyd.panex.view.PanexView;

/**
 * The <code>Panex</code> class extends the
 * <code>PanexCanvas</code> for handling the responses to the user
 * for the <code>PanexApp</code> class.
 *
 * @author	David A. Bagley
 * @author	bagleyd AT verizon.net
 * @author	https://www.sillycycle.com/puzzles.html
 */

class Panex extends PanexCanvas {
	//private static final long serialVersionUID = 42L;

	public Panex(PanexFormat model, PanexGeometry geo,
			Canvas canvas, Paint paint, PanexView panexView) {
		super(model, geo, canvas, paint, panexView);
	}

	public void PanexCon(int mode, int tiles,
			boolean mono, boolean reverse, String names,
			int pyramid0c, int pyramid1c,
			int tilec, int bg, int delay) {
		firstPaint = true;
		if (model == null) {
			model = new PanexFormat(mode, tiles);
			geo = null;
		}
		if (geo == null) {
			geo = new PanexGeometry(model);
			aDraw = null;
		}
		geo.setMono(mono);
		geo.setReverse(reverse);
		geo.setPyramidNames(names);
		geo.setPyramidColor(0, pyramid0c);
		geo.setPyramidColor(1, pyramid1c);
		geo.setTileColor(tilec);
		geo.setBackground(bg);
		geo.setDelay(delay);
		geo.setNumberSlices((delay < PanexGeometry.MAX_SLICES)
			? delay + 1 : PanexGeometry.MAX_SLICES);
		//setBackground(bg);
	}

	public boolean processKey(char key) {
		switch (key) {
		case '>':
		case '.':
			speedUpPuzzle();
			return true;
		case '<':
		case ',':
			slowDownPuzzle();
			return true;
		case '@':
			PanexView.toggleSound();
			return true;
		case '?':
			panexView.descriptionHelp();
			return true;
		case '!':
			panexView.featuresHelp();
			return true;
		case '^':
			panexView.referencesHelp();
			return true;
		/*case 'a':
		case 'A':
			((PanexApplet)applet).aboutHelp();
			return true;
		case '*':
			((PanexApplet)applet).showBuffer();
			return true;*/
		default:
		}
		if (solve != null && solve.getFlag()) {
			solve.setFlag(false);
			return false;
		}
		switch (key) {
		/*case 'g':
			getPuzzle();
			break;
		case 'w':
			writePuzzle();
			break;
		case 'G':
			getPuzzleFile();
			break;
		case 'W':
			writePuzzleFile();
			break;*/
		case 'u':
		case 'U':
			undoPuzzle();
			break;
		case 'r':
		case 'R':
			redoPuzzle();
			break;
		case 'c':
		case 'C':
			clearPuzzle();
			break;
		case 's':
		case 'S':
			solvePuzzle();
			break;
		case 'm':
		case 'M':
			modePuzzle();
			break;
		case 'i':
		case 'I':
			incrementPuzzle();
			break;
		case 'd':
		case 'D':
			decrementPuzzle();
			break;
		case 'q':
		case 'Q':
		case 'x':
		case 'X':
		//case '\03': /* Control-C */
			panexView.quit();
			break;
		default:
		}
		return true;
	}

	/*public void mousePressed(MouseEvent event) {
		int modifiers = event.getModifiersEx();

		if (movePaint || scanPaint || stackPaint || mouseDown)
			return;
		if (solve != null && solve.getFlag()) {
			solve.setFlag(false);
			return;
		}
		if (((modifiers & Event.META_DOWN_MASK) == 0) &&
				((modifiers & Event.ALT_DOWN_MASK) == 0)) {
			selectPuzzle(event.getX());
			mouseDown = true;
		} else {
			if ((event.getClickCount() & 1) == 1)
				clearWithQueryPuzzle();
			else
				clearPuzzle();
		}
	}*/

	public void mouseClicked(/*MouseEvent event*/) {
		/* Method required but mousePressed does work */
	}

	public void mouseReleased(/*MouseEvent event*/) {
		/*if (mouseDown) { // Do not care which mouse button
			releasePuzzle(event.getX());
			mouseDown = false;
		}*/
	}

	/*public void mouseEntered(MouseEvent event) {
		if (!PanexApplet.getApplication()) {
			((PanexApplet)applet).initScore();
		}
		geo.setForeground(geo.getFrameColor());
		framePaint = true;
		mouseDown = false;
		repaint();
	}

	public void mouseExited(MouseEvent event) {
		if (mouseDown && currentStack >= 0) {
			nextStack = currentStack;
			releasePaint = true;
		}
		geo.setForeground(geo.getBorderColor());
		framePaint = true;
		mouseDown = false;
		repaint();
	}

	public void mouseDragged(MouseEvent event) {
		motionPuzzle(event.getX());
	}

	public void mouseMoved(MouseEvent event) {
		*//* Method required but mousePressed does work *//*
	}

	public void keyPressed(KeyEvent event) {
		if (event.getKeyCode() == KeyEvent.VK_ESCAPE) {
			((PanexApplet)applet).shuffleDown();
			return;
		}
		processKey(event.getKeyChar());
	}*/

	public void keyReleased(/*KeyEvent event*/) {
		/* Method required but keyPressed does work */
	}

	public void keyTyped(/*KeyEvent event*/) {
		/* Method required but keyPressed does work */
	}
}
