package com.sillycycle.bagleyd.panex.model;

/*
 * @(#)PanexColumn.java
 *
 * Copyright 2014  David A. Bagley, bagleyd AT verizon.net
 *
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and
 * that both that copyright notice and this permission notice appear in
 * supporting documentation, and that the name of the author not be
 * used in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.
 *
 * This program is distributed in the hope that it will be "useful",
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

/**
 * The <code>PanexColumn</code> class part of an actual panex for
 * <code>Panex</code> class.
 *
 * @author	David A. Bagley
 * @author	bagleyd AT verizon.net
 * @author	https://www.sillycycle.com/panex.html
 */

public class PanexColumn {
	PanexTile[] tiles;
	int column;
	int slots;
	// keep around so do not have to search, but for Panex it must
	// either be reset on movement or not used
	int topPosition;

	public PanexColumn(int number, int spaces, int column) {
		this.column = column;
		this.slots = number + spaces;
		tiles = new PanexTile[this.slots];
		if (number == 0 || column == 1) {
			topPosition = -1;
			setColumn(spaces, -1);
		} else {
			topPosition = spaces;
			setColumn(spaces, (column == 0) ? 0 : 1);
		}
	}

	protected String paramString() {
		return "column:" + column +
			", slots:" + slots;
	}

	public int getColumn() {
		return column;
	}

	public int getSlots() {
		return slots;
	}

	public PanexTile getTileAtPosition(int position) {
		return tiles[position];
	}

	public void setTileAtPosition(int position, PanexTile tile) {
		tiles[position] = tile;
	}

	public void setColumn(int spaces, int color) {
		for (int depth = 0; depth < slots; depth++) {
			if (depth < spaces || color == -1) {
				tiles[depth] = new PanexTile (-1, -1);
			} else {
				tiles[depth] = new PanexTile(color, depth - spaces);
			}
		}
	}

	public int getTopTilePosition(int start) {
		int i;

		for (i = start; i < slots; i++) {
			if (tiles[i].getColor() != -1) {
				topPosition = i;
				return topPosition;
			}
		}
		topPosition = -1;
		return topPosition;
	}

	public int getTopTilePosition() {
		return getTopTilePosition(0);
	}
}
